Command

Enum Command 

pub enum Command {
    Group(GroupConfig),
    Link {
        config: DedupeConfig,
        soft: bool,
    },
    Dedupe {
        config: DedupeConfig,
    },
    Remove(DedupeConfig),
    Move {
        config: DedupeConfig,
        target: PathBuf,
    },
    Complete {
        shell: Shell,
    },
}

Variants



Group(GroupConfig)

Produce a list of groups of identical files.

Scans the given directories recursively, computes hashes of files and groups files with the same hash together. Writes the list of groups of files to the standard output, unless the target file is specified. This command is safe and does not modify the filesystem.

Replace redundant files with links.

The list of groups earlier produced by fclones group should be submitted on the standard input.

Unless --soft is specified, hard links are created. Creating hard links to files on different mount points is expected to fail.

Fields

soft: bool

Create soft (symbolic) links.



Dedupe

Deduplicate file data using native filesystem deduplication capabilities.

The list of groups earlier produced by fclones group should be submitted on the standard input.

After successful deduplication, all file clones would still be visible as distinct files, but the data would be stored only once, hence taking up possibly less space than before. Unlike with hard links, modifying a file does not modify any of its clones. The result is not visible to userland applications, so repeated runs will find the same files again. This also applies to fclones dedupe itself: The options --priority and --rf-over do not detect earlier deduplications.

This command cannot cross file system boundaries. Not all file systems support deduplication. Not all metadata is preserved on macOS. Unsupported on Windows.

Fields



Remove(DedupeConfig)

Remove redundant files.

The list of groups earlier produced by fclones group should be submitted on the standard input.



Move

Move redundant files to the given directory.

The list of groups earlier produced by fclones group should be submitted on the standard input.

Fields

target: PathBuf

Target directory where the redundant files should be moved to.



Complete

Print shell completion script to stdout.

Fields

shell: Shell

Shell for which the completion script is generated.

Implementations